<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" omit-xml-declaration="yes" indent="yes" media-type="html"/>
	<xsl:template match="/">
		<html>
			<title>
				<xsl:text>UBL Sample Purchase Order</xsl:text>
			</title>
			<body>
				<table border="0" bgcolor="white" width="600">
					<thead>
						<h1>Purchase Order (UBL Sample)</h1>
						<h2>
								<xsl:value-of select="concat('Number: ', //Identifier, ' from ')"/>				
								<xsl:call-template name="FormatDate">
									<xsl:with-param name="DateField" select="//IssueDateTime"/>
								</xsl:call-template>
						</h2>
					</thead>
				</table>
				<table border="1" width="600">
					<thead align="center" bgcolor="#00FFFF">
						<td><strong>Recipient</strong></td>
						<td><strong>Sender</strong></td>
					</thead>
					<thead align="left">
						<td>
						<xsl:apply-templates select="//BuyerParty"/></td>
						<td><xsl:apply-templates select="//SellerParty"/></td>
					</thead>
				</table>
				<br></br>
				<table border="1" width="600">
					<thead align="center" bgcolor="lime">
						<td><strong></strong></td>
						<td><strong>Identification</strong></td>
						<td><strong>Description</strong></td>
						<td><strong>Quantity</strong></td>
						<td><strong>Net Price</strong></td>
						<td><strong>Tax</strong></td>
						<td><strong>Amount</strong></td>
					</thead>
					<xsl:apply-templates select="//LineItem"/>
				</table>
				<br></br>
				<table border="1" width="600">
				<thead align="center" bgcolor="#00FFFF">
					<td><strong>Summary</strong></td>
				</thead>
				<xsl:for-each select="//Summary/*">
					<tr><td><xsl:choose>
						<xsl:when test="position() = 1">
							<xsl:value-of select="concat('Number of LineItems: ', .)"/>
						</xsl:when>
						<xsl:when test="name(./@QuantityUnitCode)">
							<xsl:call-template name="FormatQuantity">
								<xsl:with-param name="QuantityValue" select="."/>
								<xsl:with-param name="QuantityCode" select="./@QuantityUnitCode"/>
								<xsl:with-param name="QuantityName" select="name()"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="name(./@AmountCurrencyIdentificationCode)">
							<strong><xsl:call-template name="FormatAmount">
								<xsl:with-param name="AmountValue" select="."/>
								<xsl:with-param name="CurrencyValue" select="./@AmountCurrencyIdentificationCode"/>
								<xsl:with-param name="AmountName" select="name()"/>
							</xsl:call-template></strong>
						</xsl:when>
						<xsl:otherwise>
							<p><strong>Note: </strong><br/>
								<xsl:value-of select="."/>
							</p>
						</xsl:otherwise>
					</xsl:choose></td></tr>
				</xsl:for-each>
				</table>
			</body>
		</html>
	</xsl:template>
	
	<!-- Procedure the address structure -->
	<xsl:template match="BuyerParty">
		<strong><xsl:value-of select="//BuyerParty/Name"/></strong><br/>
		<xsl:value-of select="concat(//BuyerParty/Address/HouseId, ' ', //BuyerParty/Address/StreetName)"/><br/>
		<xsl:value-of select="concat(//BuyerParty/Address/CityName, ' ', //BuyerParty/Address/PostboxId)"/><br/>
		<xsl:value-of select="//BuyerParty/Address/CountryIdentificationCode"/><br/>
		<xsl:value-of select="//BuyerParty/Address/PostalZoneId"/><br/>
		<xsl:value-of select="concat('Client Code: ',//BuyerParty/Identifier)"/><br/>
	</xsl:template>
	
	<xsl:template match="SellerParty">
		<strong><xsl:value-of select="//SellerParty/Name"/></strong><br/>
		<xsl:value-of select="concat(//SellerParty/Address/HouseId, ' ', //SellerParty/Address/StreetName)"/><br/>
		<xsl:value-of select="concat(//SellerParty/Address/CityName, ' ', //SellerParty/Address/PostboxId)"/><br/>
		<xsl:value-of select="//SellerParty/Address/CountryIdentificationCode"/><br/>
		<xsl:value-of select="//SellerParty/Address/PostalZoneId"/><br/>
		<xsl:value-of select="concat('Client Code: ',//SellerParty/Identifier)"/><br/>
	</xsl:template>
	
	<!-- Procedure for realization of Rows of each LineItem -->
	<xsl:template match="LineItem">
		<thead>
			<td><xsl:value-of select="Item/ItemIdentifier"/></td>
			<td><xsl:value-of select="BuyerId"/></td>
			<td><xsl:value-of select="concat(Item/SellerItemIdentifier/Identifier,' ',Item/Description)"/></td>
			<td align="right">
				<xsl:call-template name="FormatQuantity">
					<xsl:with-param name="QuantityValue" select="Item/Measurement"/>
					<xsl:with-param name="QuantityCode" select="Item/Measurement/@MeasureUnitCode"/>
				</xsl:call-template>			
			</td>
			<td align="right">
				<xsl:call-template name="FormatAmount">
					<xsl:with-param name="AmountValue" select="Pricing/UnitPriceAmount"/>
					<xsl:with-param name="CurrencyValue" select="Pricing/UnitPriceAmount/@AmountCurrencyIdentificationCode"/>
				</xsl:call-template>			
			</td>
			<td align="right"><xsl:value-of select="concat(Tax/RatePercent, ' %')"/></td>
			<td align="right">
				<xsl:call-template name="FormatAmount">
					<xsl:with-param name="AmountValue" select="TotalAmount"/>
					<xsl:with-param name="CurrencyValue" select="TotalAmount/@AmountCurrencyIdentificationCode"/>
				</xsl:call-template>			
			</td>			
		</thead>
	</xsl:template>

	<!-- Procedure to Format Dates -->
	<xsl:template name="FormatDate">
		<xsl:param name="DateField"/>
		<xsl:value-of select="substring($DateField, 7, 2)"/>
		<xsl:text>.</xsl:text>
		<xsl:value-of select="substring($DateField, 5, 2)"/>
		<xsl:text>.</xsl:text>
		<xsl:value-of select="substring($DateField, 1, 4)"/>
	</xsl:template>
	
	<!-- Procedure to Format Amount-->
	<xsl:template name="FormatAmount">
		<xsl:param name="AmountValue"/>
		<xsl:param name="CurrencyValue"/>
		<xsl:param name="AmountName"/>
		<xsl:variable name="CType">
			<xsl:if test="$CurrencyValue='USD'">$ </xsl:if>
			<xsl:if test="$CurrencyValue='EUR'">EUR </xsl:if>
		</xsl:variable>
		<xsl:if test="$AmountName">
			<xsl:value-of select="concat($AmountName, ': ', $CType, $AmountValue)"/>
		</xsl:if>
		<xsl:if test="$AmountName=''">
			<xsl:value-of select="concat($CType, $AmountValue)"/>
		</xsl:if>
	</xsl:template>

	<!-- Procedure to Format Quantity-->
	<xsl:template name="FormatQuantity">
		<xsl:param name="QuantityValue"/>
		<xsl:param name="QuantityCode"/>
		<xsl:param name="QuantityName"/>
		<xsl:variable name="QType">
			<xsl:if test="$QuantityCode='CT'"> Cartoon</xsl:if>
			<xsl:if test="$QuantityCode='PC'"> Piece</xsl:if>
		</xsl:variable>
		<xsl:if test="$QuantityName">
			<xsl:value-of select="concat($QuantityName, ': ', $QuantityValue, $QType)"/>
		</xsl:if>
		<xsl:if test="$QuantityName=''">
			<xsl:value-of select="concat($QuantityValue, $QType)"/>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>
